@@ -16,10 +16,9 @@ Usage::
     session_client: ForecastQueryServiceClient = session.client("forecastquery")
     ```
 """
-from mypy_boto3_forecastquery.client import (
-    ForecastQueryServiceClient,
-    ForecastQueryServiceClient as Client,
-)
+from mypy_boto3_forecastquery.client import ForecastQueryServiceClient
+
+Client = ForecastQueryServiceClient
 
 
 __all__ = ("Client", "ForecastQueryServiceClient")
